remove unused variables
[project/uci.git] / uci.h
diff --git a/uci.h b/uci.h
index 1b6c9fa..574a384 100644 (file)
--- a/uci.h
+++ b/uci.h
@@ -105,6 +105,7 @@ extern void uci_perror(struct uci_context *ctx, const char *str);
  * @single: ignore the 'package' keyword and parse everything into a single package
  *
  * the name parameter is for config files that don't explicitly use the 'package <...>' keyword
+ * if 'package' points to a non-null struct pointer, enable history tracking and merge 
  */
 extern int uci_import(struct uci_context *ctx, FILE *stream, const char *name, struct uci_package **package, bool single);
 
@@ -177,20 +178,30 @@ extern int uci_set_element_value(struct uci_context *ctx, struct uci_element **e
 extern int uci_set(struct uci_context *ctx, struct uci_package *p, char *section, char *option, char *value);
 
 /**
- * uci_del_element: Delete a section or option
+ * uci_rename: Rename an element
+ * @ctx: uci context
+ * @package: package name
+ * @section: section name
+ * @option: option name
+ * @name: new name
+ */
+extern int uci_rename(struct uci_context *ctx, struct uci_package *p, char *section, char *option, char *name);
+
+/**
+ * uci_delete_element: Delete a section or option
  * @ctx: uci context
  * @e: element (section or option)
  */
-extern int uci_del_element(struct uci_context *ctx, struct uci_element *e);
+extern int uci_delete_element(struct uci_context *ctx, struct uci_element *e);
 
 /**
* uci_del: Delete a section or option
  * @ctx: uci context
  * @p: uci package
  * @section: section name
  * @option: option name (optional)
  */
-extern int uci_del(struct uci_context *ctx, struct uci_package *p, char *section, char *option);
+extern int uci_delete(struct uci_context *ctx, struct uci_package *p, char *section, char *option);
 
 /**
  * uci_save: save change history for a package
@@ -203,11 +214,12 @@ extern int uci_save(struct uci_context *ctx, struct uci_package *p);
  * uci_commit: commit changes to a package
  * @ctx: uci context
  * @p: uci_package struct pointer
+ * @overwrite: overwrite existing config data and flush history
  *
  * committing may reload the whole uci_package data,
  * the supplied pointer is updated accordingly
  */
-extern int uci_commit(struct uci_context *ctx, struct uci_package **p);
+extern int uci_commit(struct uci_context *ctx, struct uci_package **p, bool overwrite);
 
 /**
  * uci_list_configs: List available uci config files
@@ -266,6 +278,7 @@ struct uci_parse_context
        /* private: */
        struct uci_package *package;
        struct uci_section *section;
+       bool merge;
        FILE *file;
        const char *name;
        char *buf;
@@ -304,7 +317,8 @@ struct uci_option
 enum uci_command {
        UCI_CMD_ADD,
        UCI_CMD_REMOVE,
-       UCI_CMD_CHANGE
+       UCI_CMD_CHANGE,
+       UCI_CMD_RENAME
 };
 
 struct uci_history
@@ -177,20 +178,30 @@ extern int uci_set_element_value(struct uci_context *ctx, struct uci_element **e
 
 /**
- * uci_del: Delete a section or option
+ * uci_delete: Delete a section or option
  * @ctx: uci context
  * @p: uci package